# Jockbot NHL


[![Total alerts](https://img.shields.io/lgtm/alerts/g/jalgraves/jockbot_nhl.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jalgraves/jockbot_nhl/alerts/)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/jalgraves/jockbot_nhl.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jalgraves/jockbot_nhl/context:python)

### Interact with NHL API

##### Install
    pip3 install jockbot_nhl
